@@ -24,6 +24,7 @@
 #include "../basicindexingjob.h"
 #include "../database.h"
 #include "xapiandatabase.h"
+#include "../fileindexerconfig.h"
 
 #include <KCmdLineArgs>
 #include <KMimeType>
@@ -64,6 +65,8 @@ App::App(QObject* parent)
     m_bData = args->isSet("bdata");
     m_debugEnabled = args->isSet("debug");
 
+    FileIndexerConfig config;
+
     m_results.reserve(args->count());
     for (int i=0; i<args->count(); i++) {
         FileMapping mapping = FileMapping(args->arg(i).toUInt());
@@ -81,11 +84,11 @@ App::App(QObject* parent)
             url = args->url(i).toLocalFile();
         }
 
-        if (QFile::exists(url)) {
+        if (QFile::exists(url) && config.shouldBeIndexed(url)) {
             m_urls << url;
         } else {
             // id or url was looked up, but file deleted
-            kDebug() << url << "does not exist";
+            kDebug() << url << "does not exist or should not be indexed";
 
             // Try to delete it as an id:
             // it may have been deleted from the FileMapping db as well.
@@ -117,7 +120,23 @@ void App::processNextUrl()
     }
 
     const QString url = m_urls.takeFirst();
-    const QString mimetype = KMimeType::findByUrl(KUrl::fromLocalFile(url))->name();
+    QString mimetype = KMimeType::findByUrl(KUrl::fromLocalFile(url))->name();
+
+    //
+    // HACK: We only want to index plain text files which end with a .txt
+    // Also, we're ignoring txt files which are greater tha 50 Mb as we
+    // have trouble processing them
+    //
+    if (mimetype == QLatin1String("text/plain")) {
+        if (!url.endsWith(".txt")) {
+            mimetype.clear();
+        }
+
+        QFileInfo fileInfo(url);
+        if (fileInfo.size() >= 50 * 1024 * 1024 ) {
+            mimetype.clear();
+        }
+    }
 
     FileMapping file(url);
     if (!m_bData) {
