@@ -41,6 +41,8 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 
+#include <QFile>
+
 namespace {
     QString dbPath(const QString& dbName) {
         QString basePath = "baloo";
@@ -63,7 +65,7 @@ namespace {
     }
 }
 
-#define INDEXING_AGENT_VERSION 3
+#define INDEXING_AGENT_VERSION 4
 
 BalooIndexingAgent::BalooIndexingAgent(const QString& id)
     : AgentBase(id),
@@ -144,7 +146,7 @@ qlonglong BalooIndexingAgent::indexedItemsInDatabase(const std::string& term, co
 {
     Xapian::Database db;
     try {
-        db = Xapian::Database(dbPath.toStdString());
+        db = Xapian::Database(QFile::encodeName(dbPath).constData());
     } catch (const Xapian::DatabaseError& e) {
         kError() << "Failed to open database" << dbPath << ":" << QString::fromStdString(e.get_msg());
         return 0;
