@@ -54,6 +54,11 @@ XapianDatabase::XapianDatabase(const QString& path, bool writeOnly)
     }
 }
 
+XapianDatabase::~XapianDatabase()
+{
+    delete m_db;
+}
+
 void XapianDatabase::replaceDocument(uint id, const XapianDocument& doc)
 {
     replaceDocument(id, doc.doc());
@@ -133,7 +138,9 @@ void XapianDatabase::commit()
     m_docsToAdd.clear();
     m_docsToRemove.clear();
 
+#ifdef __GNUC__
     malloc_trim(0);
+#endif
 }
 
 XapianDocument XapianDatabase::document(uint id)
