@@ -174,7 +174,7 @@ namespace {
 Xapian::Query XapianSearchStore::constructSearchQuery(const QString& str)
 {
     QVector<Xapian::Query> queries;
-    QRegExp splitRegex("[\\s.]");
+    QRegExp splitRegex("[\\s.+*/\\-=]");
     QStringList list = str.split(splitRegex, QString::SkipEmptyParts);
 
     QMutableListIterator<QString> iter(list);
@@ -205,43 +205,46 @@ int XapianSearchStore::exec(const Query& query)
     if (!m_db)
         return 0;
 
-    QMutexLocker lock(&m_mutex);
-    try {
-        m_db->reopen();
-    } catch (Xapian::DatabaseError& e) {
-        kWarning() << "Failed to reopen database" << dbPath() << ":" <<  QString::fromStdString(e.get_msg());
-        return 0;
+    while (1) {
+        try {
+            QMutexLocker lock(&m_mutex);
+            try {
+                m_db->reopen();
+            } catch (Xapian::DatabaseError& e) {
+                kWarning() << "Failed to reopen database" << dbPath() << ":" <<  QString::fromStdString(e.get_msg());
+                return 0;
+            }
+
+            Xapian::Query xapQ = toXapianQuery(query.term());
+            if (query.searchString().size()) {
+                QString str = query.searchString();
+
+                Xapian::Query q = constructSearchQuery(str);
+                xapQ = andQuery(xapQ, q);
+            }
+            xapQ = andQuery(xapQ, convertTypes(query.types()));
+            xapQ = andQuery(xapQ, constructFilterQuery(query.yearFilter(), query.monthFilter(), query.dayFilter()));
+            xapQ = applyCustomOptions(xapQ, query.customOptions());
+            xapQ = finalizeQuery(xapQ);
+
+            Xapian::Enquire enquire(*m_db);
+            enquire.set_query(xapQ);
+
+            Result& res = m_queryMap[m_nextId++];
+            res.mset = enquire.get_mset(query.offset(), query.limit());
+            res.it = res.mset.begin();
+
+            return m_nextId-1;
+        }
+        catch (const Xapian::DatabaseModifiedError&) {
+            continue;
+        }
+        catch (const Xapian::Error&) {
+            return 0;
+        }
     }
 
-    QTime queryGenerationTimer;
-    queryGenerationTimer.start();
-
-    Xapian::Query xapQ = toXapianQuery(query.term());
-    if (query.searchString().size()) {
-        QString str = query.searchString();
-
-        Xapian::Query q = constructSearchQuery(str);
-        xapQ = andQuery(xapQ, q);
-    }
-    xapQ = andQuery(xapQ, convertTypes(query.types()));
-    xapQ = andQuery(xapQ, constructFilterQuery(query.yearFilter(), query.monthFilter(), query.dayFilter()));
-    xapQ = applyCustomOptions(xapQ, query.customOptions());
-    xapQ = finalizeQuery(xapQ);
-
-    Xapian::Enquire enquire(*m_db);
-    kDebug() << xapQ.get_description().c_str();
-    enquire.set_query(xapQ);
-
-    kDebug() << "Query Generation" << queryGenerationTimer.elapsed();
-
-    Result& res = m_queryMap[m_nextId++];
-    QTime timer;
-    timer.start();
-    res.mset = enquire.get_mset(query.offset(), query.limit());
-    res.it = res.mset.begin();
-
-    kDebug() << "Exec" << timer.elapsed() << "msecs";
-    return m_nextId-1;
+    return 0;
 }
 
 void XapianSearchStore::close(int queryId)
@@ -321,6 +324,9 @@ Xapian::Document XapianSearchStore::docForQuery(int queryId)
         m_db->reopen();
         return docForQuery(queryId);
     }
+    catch (const Xapian::Error&) {
+        return Xapian::Document();
+    }
 }
 
 Xapian::Database* XapianSearchStore::xapianDb()
